@@ -27,7 +27,14 @@ def load(
 
     opt = hub.config.order.apply(raw, raw_cli, cli, cli_args, os_vars, configs)
     # Sync pop-config with the log-level
-    opt["pop_config"] = {k: opt[sources[0]][k] for k in opt["pop_config"]}
+    opt["pop_config"] = {
+        k: opt[sources[0]][k] for k in opt["pop_config"] if k in opt[sources[0]]
+    }
+
+    # Output a config based on the current os and cli parameters
+    if cli_args.get("config_template"):
+        hub.config.template.run(opt)
+
     hub.OPT = hub.pop.data.imap(opt)
 
     if logs:
