@@ -30,12 +30,14 @@ def setup(hub, conf):
     ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
     if ":" in conf["log_file"]:
         host, port = conf["log_file"].split(":")
+        if port:
+            port = int(port)
     else:
         # Open a unix socket
         host = conf["log_file"]
         port = None
-    _, kwargs = hub.render.cli.args(conf["log_handler_options"])
-    fh = logging.handlers.DatagramHandler(host=host, port=port, **kwargs)
+    # _, kwargs = hub.render.cli.args(conf["log_handler_options"])
+    fh = logging.handlers.DatagramHandler(host=host, port=port)
     fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
     root.addHandler(fh)
