@@ -5,17 +5,15 @@ from typing import Tuple
 try:
     import yaml
 
-    HAS_YAML = True
-except ImportError:
-    HAS_YAML = False
+    HAS_YAML = (True,)
+except ImportError as e:
+    HAS_YAML = False, str(e)
 
 __virtualname__ = "cli"
 
 
 def __virtual__(hub):
-    if HAS_YAML:
-        return True
-    return (False, "PyYaml could not be loaded")
+    return HAS_YAML
 
 
 def load(hub, path):
